@@ -1,9 +1,11 @@
 #!/usr/bin/python
 """Hyperion Constants."""
 
+KEY_ACCEPT = "accept"
 KEY_ADJUSTMENT = "adjustment"
 KEY_AUTHORIZE = "authorize"
 KEY_AUTHORIZE_LOGIN = "authorize-login"
+KEY_AUTHORIZE_LOGOUT = "authorize-logout"
 KEY_BRIGHTNESS = "brightness"
 KEY_CLEAR = "clear"
 KEY_COLOR = "color"
@@ -17,30 +19,51 @@ KEY_EFFECTS = "effects"
 KEY_ENABLED = "enabled"
 KEY_LED_MAPPING = "imageToLedMapping"
 KEY_LED_MAPPING_TYPE = "imageToLedMappingType"
+KEY_ID = "id"
+KEY_IMAGE = "image"
+KEY_IMAGE_STREAM_START = "imagestream-start"
+KEY_IMAGE_STREAM_STOP = "imagestream-stop"
 KEY_INFO = "info"
 KEY_INSTANCE = "instance"
+KEY_LEDCOLORS = "ledcolors"
+KEY_LED_STREAM_START = "ledstream-start"
+KEY_LED_STREAM_STOP = "ledstream-stop"
 KEY_LEDS = "leds"
 KEY_LED_MAPPING = "imageToLedMapping"
 KEY_LOGIN = "login"
+KEY_LOGOUT = "logout"
 KEY_NAME = "name"
 KEY_ORIGIN = "origin"
 KEY_OWNER = "owner"
 KEY_PRIORITY = "priority"
 KEY_PRIORITIES = "priorities"
+KEY_PRIORITIES_AUTOSELECT = "priorities_autoselect"
+KEY_PROCESSING = "processing"
 KEY_RGB = "RGB"
+KEY_REQUIRED = "required"
+KEY_REQUEST_TOKEN = "requestToken"
+KEY_RUNNING = "running"
 KEY_SESSIONS = "sessions"
+KEY_SET_VIDEOMODE = "videoMode"
 KEY_SERVERINFO = "serverinfo"
+KEY_SOURCESELECT = "sourceselect"
+KEY_START_INSTANCE = "startInstance"
+KEY_STOP_INSTANCE = "stopInstance"
 KEY_SUBCOMMAND = "subcommand"
 KEY_SUBSCRIBE = "subscribe"
 KEY_SUCCESS = "success"
 KEY_SWITCH_TO = "switchTo"
 KEY_STATE = "state"
+KEY_TAN = "tan"
 KEY_TOKEN = "token"
+KEY_TOKEN_REQUIRED = "tokenRequired"
 KEY_UPDATE = "update"
 KEY_VALUE = "value"
 KEY_VIDEOMODE = "videomode"
 KEY_VISIBLE = "visible"
 
+KEY_VIDEOMODES = ["2D", "3DSBS", "3DTAB"]
+
 # ComponentIDs from: https://docs.hyperion-project.org/en/json/Control.html#components-ids-explained
 KEY_COMPONENTID = "componentId"
 KEY_COMPONENTID_ALL = "ALL"
@@ -58,3 +81,4 @@ KEY_COMPONENTID_V4L = "V4L"
 DEFAULT_INSTANCE = 0
 DEFAULT_CONNECTION_RETRY_DELAY = 30
 DEFAULT_CONNECTION_TIMEOUT_SECS = 5
+DEFAULT_ORIGIN = "hyperion-py"
